@@ -3,4 +3,4 @@ from .pickles import dump_pickle, load_pickle
 from .unzip import unzip
 from .str_utils import color_str
 from .seeds import tf_set_seed
-from .logging_ import get_logger
+from .logging_ import get_logger, log_print, value_error_log
